@@ -1,3 +1,4 @@
+import io
 from typing import Any
 
 from .model import EHentaiResponse
@@ -17,19 +18,23 @@ class EHentai(HandOver):
         self.similar: bool = similar
         self.exp: bool = exp
 
-    async def search(self, file_path: str, ex: bool = False) -> EHentaiResponse:
-        url = (
+    async def search(self, url: str, ex: bool = False) -> EHentaiResponse:
+        _url = (
             "https://exhentai.org/upld/image_lookup.php"
             if ex
             else "https://upld.e-hentai.org/image_lookup.php"
         )
         data = {"f_sfile": "search"}
-        files = {"sfile": open(file_path, "rb")}
+        if url.startswith("http"):  # 网络url
+            file_content = io.BytesIO((await self.get(url)).content)
+            files = {"sfile": file_content}
+        else:  # 本地文件
+            files = {"sfile": open(url, "rb")}  # type: ignore
         if self.covers:
             data["fs_covers"] = "on"
         if self.similar:
             data["fs_similar"] = "on"
         if self.exp:
             data["fs_exp"] = "on"
-        resp = await self.post(url=url, data=data, files=files)
+        resp = await self.post(url=_url, data=data, files=files)
         return EHentaiResponse(resp)
